<?php

namespace Drupal\iubenda_integration\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Defines a form that configures iubenda_integration settings.
 */
class IubendaSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'iubenda_integration_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'iubenda_integration.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    $iubenda_config = $this->config('iubenda_integration.settings');

    $form['settings'] = [
      '#type' => 'vertical_tabs',
      '#title' => t('Iubenda privacy policy'),
    ];

    // Iubenda tab.
    $form['iubenda'] = [
      '#type' => 'details',
      '#title' => t('General'),
      '#group' => 'settings',
    ];
    $form['iubenda']['iubenda_integration_policy_code'] = [
      '#title' => t('Iubenda Privacy Policy code'),
      '#type' => 'textfield',
      '#description' => t('Insert the privacy policy code generated by Iubenda
        for your website.'),
      '#default_value' => $iubenda_config
        ->get('iubenda_integration_policy_code'),
      //'value' => $form_state->getValue('iubenda_integration_policy_code'),
      '#required' => TRUE,
      '#size' => 10,
    ];
    $form['iubenda']['iubenda_integration_style'] = [
      '#title' => t('Style'),
      '#type' => 'radios',
      '#options' => [
        'iubenda-nostyle' => t('No style'),
        'iubenda-white' => t('White'),
        'iubenda-black' => t('Black'),
      ],
      '#default_value' => $iubenda_config->get('iubenda_integration_style'),
      '#required' => TRUE,
    ];
    $form['iubenda']['iubenda_integration_legal_only'] = [
      '#title' => t('Show legal only'),
      '#type' => 'checkbox',
      '#default_value' => $iubenda_config
        ->get('iubenda_integration_legal_only'),
    ];
    $form['iubenda']['iubenda_integration_show_brand'] = [
      '#title' => t('Show brand'),
      '#type' => 'checkbox',
      '#default_value' => $iubenda_config
        ->get('iubenda_integration_show_brand'),
    ];

    // Form tab.
    $form['form'] = [
      '#type' => 'details',
      '#title' => t('Form'),
      '#group' => 'settings',
    ];
    $form['form']['iubenda_integration_form_element_type'] = [
      '#title' => t('Form element type'),
      '#type' => 'select',
      '#options' => [
        'checkbox' => t('Checkbox'),
        'radio' => t('Radio'),
      ],
      '#default_value' => $iubenda_config
        ->get('iubenda_integration_form_element_type'),
    ];
    $form['form']['iubenda_integration_forms'] = [
      '#title' => t('Privacy Policy Forms'),
      '#description' => t('Insert here, one per line, a list of form ids for
        which Iubenda Privacy Policy have to be displayed.'),
      '#type' => 'textarea',
      '#default_value' => $iubenda_config->get('iubenda_integration_forms'),
    ];
    $form['form']['text'] = [
      '#title' => t('Text'),
      '#type' => 'fieldset',
    ];
    $form['form']['text']['iubenda_integration_pretext'] = [
      '#title' => t('Pre-Text'),
      '#description' => t('Insert text of the Privacy Policy line have to
        precede Iubenda link'),
      '#type' => 'textarea',
      '#default_value' => $iubenda_config->get('iubenda_integration_pretext'),
    ];
    $form['form']['text']['iubenda_integration_text'] = [
      '#title' => t('Link Text'),
      '#description' => t('Insert text that will be displayed as link'),
      '#type' => 'textfield',
      '#default_value' => $iubenda_config->get('iubenda_integration_text'),
      '#required' => TRUE,
    ];
    $form['form']['text']['iubenda_integration_posttext'] = [
      '#title' => t('Post-Text'),
      '#description' => t('Insert text of the Privacy Policy line have to follow
        Iubenda link'),
      '#type' => 'textarea',
      '#default_value' => $iubenda_config->get('iubenda_integration_posttext'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    // Save settings.
    foreach ($form_state->getValues() as $key => $value) {
      //drupal_set_message($key . ': ' . $value);
      $this->config('iubenda_integration.settings')
        ->set($key, $form_state->getValue($key))
        ->save();
    }

    parent::submitForm($form, $form_state);
  }

}
